@@ -7,27 +7,28 @@ from __future__ import absolute_import
 # ruamel.base installed __init__.py, and thus a new version should
 # be installed at some point
 
-null = None
-_package_data = {   # JSON
-    "full_package_name": "ruamel.yaml",
-    "version_info": [0, 10, 8],
-    "author": "Anthon van der Neut",
-    "author_email": "a.van.der.neut@ruamel.eu",
-    "description": "ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order",  # NOQA
-    "entry_points": null,
-    "install_requires": {
-        "any": ["ruamel.base>=1.0.0"],
-        "py26": ["ruamel.ordereddict"],
-        "py27": ["ruamel.ordereddict"]
-    },
-    "ext_modules": [ {
-        "name": "_ruamel_yaml",
-        "src": ["ext/_ruamel_yaml.c"],
-        "lib": ["yaml"],
-        "test": "#include <yaml.h>\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n"  # NOQA
-        }
+_package_data = dict(
+    full_package_name="ruamel.yaml",
+    version_info=[0, 10, 11],
+    author="Anthon van der Neut",
+    author_email="a.van.der.neut@ruamel.eu",
+    description="ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order",  # NOQA
+    entry_points=None,
+    install_requires=dict(
+        any=["ruamel.base>=1.0.0"],
+        py26=["ruamel.ordereddict"],
+        py27=["ruamel.ordereddict"]
+    ),
+    ext_modules=[ dict(
+        name="_ruamel_yaml",
+        src=["ext/_ruamel_yaml.c", "ext/api.c", "ext/writer.c", "ext/dumper.c",
+                "ext/loader.c", "ext/reader.c", "ext/scanner.c", "ext/parser.c",
+                "ext/emitter.c"],
+        lib=[],
+        # test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n'  # NOQA
+        )
     ],
-    "classifiers": [
+    classifiers=[
         "Programming Language :: Python :: 2.6",
         "Programming Language :: Python :: 2.7",
         "Programming Language :: Python :: 3.3",
@@ -37,7 +38,7 @@ _package_data = {   # JSON
         "Topic :: Software Development :: Libraries :: Python Modules",
         "Topic :: Text Processing :: Markup"
     ]
-}   # JSON
+)
 
 
 # < from ruamel.util.new import _convert_version
